# Generated by Django 2.0.1 on 2018-06-19 06:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0010_auto_20180208_2356")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="sap_pernr",
            field=models.IntegerField(blank=True, null=True, verbose_name="SAP Pernr"),
        )
    ]
