# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-01 17:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0003_myuser_crm_contact_id")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="avatar_attachment_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="avatar attachment id"
            ),
        ),
        migrations.AddField(
            model_name="myuser",
            name="company_logo_attachment_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="company logo attachment id"
            ),
        ),
        migrations.AddField(
            model_name="myuser",
            name="um_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="user management id"
            ),
        ),
    ]
